# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-21 11:20
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fido', '0006_fill_empty_attestation'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authenticator',
            name='attestation_data',
            field=models.TextField(),
        ),
    ]
